# ericsbandnames
Pull the latest band names from http://ericsbandnames.com

## please use responsibly
We dont want to inadvertently DDOS Eric's website, so please cache your queries and limit the amount of traffic to the site

## examples
```
from ericsbandnames import random_band_name, list_band_names

band_name = random_band_name()
all_band_names = list_band_names()

print(band_name)
print(all_band_names)
```

